"""multistage restore imaging scripts

Revision ID: bd32e3fa12ac
Revises: 4cb741e8606a
Create Date: 2021-10-08 15:48:15.278013

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = "bd32e3fa12ac"
down_revision = "4cb741e8606a"
branch_labels = None
depends_on = None


fetch_content = """#!/bin/sh
set -o errexit

export HOME=$TMPDIR

./framework.sh -d .
chmod 770 .
cd rawdata/
../productfetcher --product-locator $1 --product-locator $2
cd ../

"""

envoy_content = """#!/bin/sh
set -o errexit

export HOME=$TMPDIR
{{#remote}}
export CAPO_PATH=.
export CAPO_PROFILE={{profile}}
{{/remote}}

./casa_envoy --integrated -i $1 $2

"""

deliver_content = """#!/bin/sh
set -o errexit

export HOME=$TMPDIR

./deliver -p ./products --prefix $1

"""

old_content = """#!/bin/sh

export HOME=$TMPDIR

set -o errexit
./framework.sh -d .
chmod 770 .
cd rawdata/
../productfetcher --product-locator $1 --product-locator $2
cd ../
./casa_envoy --integrated -i $4 $5
./deliver -p ./products --prefix $3
"""


def upgrade():
    op.execute(
        """
        DELETE FROM workflow_templates WHERE filename='std_restore_imaging.sh'
        """
    )
    op.execute(
        f"""
            INSERT INTO workflow_templates (filename, content, workflow_name) 
            VALUES ('std_restore_imaging_fetch.sh', E'{fetch_content}', 'std_restore_imaging') 
            """
    )
    op.execute(
        f"""
            INSERT INTO workflow_templates (filename, content, workflow_name) 
            VALUES ('std_restore_imaging_envoy.sh', E'{envoy_content}', 'std_restore_imaging') 
            """
    )
    op.execute(
        f"""
            INSERT INTO workflow_templates (filename, content, workflow_name) 
            VALUES ('std_restore_imaging_deliver.sh', E'{deliver_content}', 'std_restore_imaging') 
            """
    )


def downgrade():
    op.execute(
        """
        DELETE FROM workflow_templates 
        WHERE filename like ('std_restore_imaging_%.sh') 
        AND workflow_name = 'std_restore_imaging'
        """
    )

    op.execute(
        f"""
            INSERT INTO workflow_templates (filename, content, workflow_name) 
            VALUES ('std_restore_imaging.sh', E'{old_content}', 'std_restore_imaging')
            """
    )
