"""add ingest_img workflow

Revision ID: dcbfdfafe16c
Revises: f2e524e1e04d
Create Date: 2021-07-27 15:38:06.960178

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = "dcbfdfafe16c"
down_revision = "f2e524e1e04d"
branch_labels = None
depends_on = None

condor_content = """executable = ingest_image.sh
arguments = metadata.json

output = ingest.out
error = ingest.err
log = condor.log

SBIN_PATH = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/sbin
should_transfer_files = yes
transfer_input_files = $(SBIN_PATH)/pycapo, $(SBIN_PATH)/conveyor, $(SBIN_PATH)/ingest_envoy, $(SBIN_PATH)/ingest, $(SBIN_PATH)/image-product-collector.sh, ./metadata.json

getenv = True
environment = "CAPO_PATH=/home/casa/capo"

queue


"""

script_content = """#!/bin/sh
set -o errexit

./conveyor --retrieve-img $1
./ingest_envoy --image $1

"""


def upgrade():
    op.execute(
        f"""
        INSERT INTO workflows (workflow_name)
        VALUES ('ingest_image')
        """
    )
    op.execute(
        f"""
        INSERT INTO workflow_templates (filename, content, workflow_name) 
        VALUES ('ingest_image.condor', E'{condor_content}', 'ingest_image') 
        """
    )
    op.execute(
        f"""
        INSERT INTO workflow_templates (filename, content, workflow_name) 
        VALUES ('ingest_image.sh', E'{script_content}', 'ingest_image') 
        """
    )


def downgrade():
    op.execute(
        """
        DELETE FROM workflows WHERE workflow_name='ingest_image'
        """
    )
    op.execute(
        """
        DELETE FROM workflow_templates WHERE workflow_name='ingest_image'
        """
    )
